Skip to contents

This UI module defines the table panel layout for displaying data in a reactive table and provides an option to download the results as a CSV file.

Usage

table_ui(id)

Arguments

id

Character string used for namespacing the input IDs in the UI module.

Value

A nav_panel containing the data table and download button.