UI Module: Header
header_ui.RdA Shiny UI module that displays the application header, including the title, GitHub repository link, and an info button.
header_ui.RdA Shiny UI module that displays the application header, including the title, GitHub repository link, and an info button.