UI Module: Display Instructions Pop up for the App
info_ui.RdThis function creates a reusable modal dialog in Shiny that provides users with instructions on how to use the app. It includes a welcome message, information about the data sources (ENA and GBIF), and step-by-step guidance for navigating the app.
Value
A shiny::modalDialog object to be used with shiny::showModal().