UI Module: Map Tab
map_ui.RdDefines the user interface for the Map tab of the Odyssey Shiny application. This tab displays an interactive Leaflet map that visualizes molecular biodiversity data.
map_ui.RdDefines the user interface for the Map tab of the Odyssey Shiny application. This tab displays an interactive Leaflet map that visualizes molecular biodiversity data.