Server Module: Overview Tab - Area Plot of Observations Over Time
plot_server1.RdServer module that generates an interactive area chart displaying the number of observations
(based on first_public dates) over time, grouped by year and month.
This plot is used in the Overview tab and is rendered using the echarts4r package.