UI Module: Table Tab - Table Display
table_ui.RdThis UI module defines the table panel layout for displaying data in a reactive table and provides an option to download the results as a CSV file.
table_ui.RdThis UI module defines the table panel layout for displaying data in a reactive table and provides an option to download the results as a CSV file.