text_server2.Rd
This server module returns the number of unique taxonomic divisions in the dataset, typically used in the Table Tab to summarize diversity.
text_server2(id, df)
Character string for namespacing the module
A reactive data.table; the dataset for which unique taxonomic divisions are counted
data.table
A numeric value representing the count of unique tax_division2 entries
tax_division2